@@ -31,6 +31,7 @@ from cnvrgv2.utils.api_list_generator import api_list_generator
 
 from cnvrgv2.modules.file import File
 from cnvrgv2.modules.base.dynamic_attributes import DynamicAttributes
+from cnvrgv2.utils.validators import validate_directory_name
 
 
 class DataOwner(DynamicAttributes):
@@ -238,7 +239,9 @@ class DataOwner(DynamicAttributes):
             return
 
         if job_slug is not None:
-            last_commit = self.last_commit or self.start_commit["sha1"]
+            last_commit = self.last_commit
+            if last_commit is None and self.start_commit is not None:
+                last_commit = self.start_commit["sha1"]
 
         new_unique_fullpaths = []
         tmp_folder = "{}/{}".format(self.working_dir, DataOwner.TMP_FOLDER_NAME)
@@ -248,6 +251,8 @@ class DataOwner(DynamicAttributes):
             if not os.path.isfile(deleted_file):
                 new_unique_fullpaths.append(up)
 
+        validate_directory_name(new_unique_fullpaths)
+
         commit_sha1 = self._start_commit(
             message=message,
             blank=blank,
